@@ -1,6 +1,6 @@
 ''' Module containing Agent RTM API client implementation for v3.3. '''
 
-from typing import Any, Optional, Union
+from typing import Any, Callable, Optional, Union
 
 from livechat.utils.helpers import prepare_payload
 from livechat.utils.structures import AccessToken, RtmResponse
@@ -11,15 +11,21 @@ from livechat.utils.ws_client import WebsocketClient
 
 class AgentRtmV33:
     ''' Agent RTM API Class containing methods in version 3.3. '''
-    def __init__(self, url: str):
-        self.ws = WebsocketClient(url=f'wss://{url}/v3.3/agent/rtm/ws')
+    def __init__(
+        self,
+        url: str,
+        header: Union[list, dict, Callable, None],
+    ):
+        self.ws = WebsocketClient(url=f'wss://{url}/v3.3/agent/rtm/ws',
+                                  header=header)
 
     def open_connection(self,
                         origin: dict = None,
-                        ping_timeout: float = 3,
-                        ping_interval: float = 5,
-                        ws_conn_timeout: float = 10,
-                        keep_alive: bool = True) -> None:
+                        ping_timeout: Union[float, int] = 3,
+                        ping_interval: Union[float, int] = 5,
+                        ws_conn_timeout: Union[float, int] = 10,
+                        keep_alive: bool = True,
+                        response_timeout: Union[float, int] = 3) -> None:
         ''' Opens WebSocket connection.
 
             Args:
@@ -31,9 +37,11 @@ class AgentRtmV33:
                 ws_conn_timeout (int or float): timeout (in seconds) to wait for WebSocket connection,
                     by default sets to 10 seconds.
                 keep_alive(bool): Bool which states if connection should be kept, by default sets to `True`.
+                response_timeout (int or float): timeout (in seconds) to wait for the response,
+                    by default sets to 3 seconds.
         '''
         self.ws.open(origin, ping_timeout, ping_interval, ws_conn_timeout,
-                     keep_alive)
+                     keep_alive, response_timeout)
 
     def close_connection(self) -> None:
         ''' Closes WebSocket connection. '''
