@@ -2,7 +2,7 @@
 
 # pylint: disable=C0103,R0903,R0913,W0107,W0231,W0613,W0622
 
-from typing import Optional, Union
+from typing import Callable, Optional, Union
 
 from livechat.utils.helpers import prepare_payload
 from livechat.utils.structures import AccessToken, RtmResponse
@@ -11,12 +11,17 @@ from livechat.utils.ws_client import WebsocketClient
 
 class CustomerRtmV35:
     ''' Customer RTM API client class in version 3.5. '''
-    def __init__(self, organization_id: str, base_url: str):
+    def __init__(
+        self,
+        organization_id: str,
+        base_url: str,
+        header: Union[list, dict, Callable, None],
+    ):
         if isinstance(organization_id, str):
             self.ws = WebsocketClient(
                 url=
-                f'wss://{base_url}/v3.5/customer/rtm/ws?organization_id={organization_id}'
-            )
+                f'wss://{base_url}/v3.5/customer/rtm/ws?organization_id={organization_id}',
+                header=header)
         else:
             raise ValueError(
                 f'Provided `organization_id` (`{organization_id}`) seems invalid. Websocket connection may not open.'
@@ -24,10 +29,11 @@ class CustomerRtmV35:
 
     def open_connection(self,
                         origin: dict = None,
-                        ping_timeout: float = 3,
-                        ping_interval: float = 5,
-                        ws_conn_timeout: float = 10,
-                        keep_alive: bool = True) -> None:
+                        ping_timeout: Union[float, int] = 3,
+                        ping_interval: Union[float, int] = 5,
+                        ws_conn_timeout: Union[float, int] = 10,
+                        keep_alive: bool = True,
+                        response_timeout: Union[float, int] = 3) -> None:
         ''' Opens WebSocket connection.
 
             Args:
@@ -39,9 +45,11 @@ class CustomerRtmV35:
                 ws_conn_timeout (int or float): timeout (in seconds) to wait for WebSocket connection,
                     by default sets to 10 seconds.
                 keep_alive(bool): Bool which states if connection should be kept, by default sets to `True`.
+                response_timeout (int or float): timeout (in seconds) to wait for the response,
+                    by default sets to 3 seconds.
         '''
         self.ws.open(origin, ping_timeout, ping_interval, ws_conn_timeout,
-                     keep_alive)
+                     keep_alive, response_timeout)
 
     def close_connection(self) -> None:
         ''' Closes WebSocket connection. '''
