@@ -8,6 +8,8 @@ from livechat.utils.helpers import prepare_payload
 from livechat.utils.http_client import HttpClient
 from livechat.utils.structures import AccessToken
 
+# pylint: disable=unused-argument,too-many-arguments
+
 
 class ReportsApiV36(HttpClient):
     ''' Reports API client class in version 3.6. '''
@@ -47,7 +49,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                            which contains a server’s response to an HTTP request.
+                            which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -77,7 +79,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -107,7 +109,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -137,7 +139,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -167,7 +169,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -197,7 +199,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -227,7 +229,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                            which contains a server’s response to an HTTP request.
+                            which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -235,12 +237,13 @@ class ReportsApiV36(HttpClient):
                                  json=payload,
                                  headers=headers)
 
-    def surveys(self,
-                timezone: str = None,
-                filters: dict = None,
-                payload: dict = None,
-                headers: dict = None) -> httpx.Response:
-        ''' Returns the number of submitted chat surveys along with the count of specific answers.
+    def forms(self,
+              timezone: str = None,
+              filters: dict = None,
+              payload: dict = None,
+              headers: dict = None) -> httpx.Response:
+        ''' Returns the number of submitted chat forms along with the count of specific answers.
+
 
         Args:
             timezone (str): IANA Time Zone (e.g. America/Phoenix).
@@ -255,11 +258,11 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                            which contains a server’s response to an HTTP request.
+                            which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
-        return self.session.post(f'{self.api_url}/chats/surveys',
+        return self.session.post(f'{self.api_url}/chats/forms',
                                  json=payload,
                                  headers=headers)
 
@@ -285,7 +288,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                            which contains a server’s response to an HTTP request.
+                            which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -315,7 +318,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                            which contains a server’s response to an HTTP request.
+                            which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -323,6 +326,96 @@ class ReportsApiV36(HttpClient):
                                  json=payload,
                                  headers=headers)
 
+    def groups(self,
+               distribution: str = None,
+               timezone: str = None,
+               filters: dict = None,
+               payload: dict = None,
+               headers: dict = None) -> httpx.Response:
+        ''' Shows the total number of chats handled by each group during the specified period.
+
+        Args:
+            distribution (str): Allowed values: `hour`, `day`, `day-hours`, `month` or `year`. Defaults to `day`.
+            timezone (str): IANA Time Zone (e.g. America/Phoenix).
+                            Defaults to the requester's timezone.
+                            When the requester's timezone isn't present, then `filters.from` is parsed to get the timezone.
+            filters (dict): If none provided, your report will span the last seven days.
+            payload (dict): Custom payload to be used as request's data.
+                            It overrides all other parameters provided for the method.
+            headers (dict): Custom headers to be used with session headers.
+                            They will be merged with session-level values that are set,
+                            however, these method-level parameters will not be persisted across requests.
+
+        Returns:
+            httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/chats/groups',
+                                 json=payload,
+                                 headers=headers)
+
+    def queued_visitors(self,
+                        distribution: str = None,
+                        timezone: str = None,
+                        filters: dict = None,
+                        payload: dict = None,
+                        headers: dict = None) -> httpx.Response:
+        ''' Shows how many customers were waiting in the queue during the specified period.
+
+        Args:
+            distribution (str): Allowed values: `hour`, `day`, `day-hours`, `month` or `year`. Defaults to `day`.
+            timezone (str): IANA Time Zone (e.g. America/Phoenix).
+                            Defaults to the requester's timezone.
+                            When the requester's timezone isn't present, then `filters.from` is parsed to get the timezone.
+            filters (dict): If none provided, your report will span the last seven days.
+            payload (dict): Custom payload to be used as request's data.
+                            It overrides all other parameters provided for the method.
+            headers (dict): Custom headers to be used with session headers.
+                            They will be merged with session-level values that are set,
+                            however, these method-level parameters will not be persisted across requests.
+
+        Returns:
+            httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/chats/queued_visitors',
+                                 json=payload,
+                                 headers=headers)
+
+    def queued_visitors_left(self,
+                             distribution: str = None,
+                             timezone: str = None,
+                             filters: dict = None,
+                             payload: dict = None,
+                             headers: dict = None) -> httpx.Response:
+        ''' Shows customers that left the queue during the specified period.
+
+        Args:
+            distribution (str): Allowed values: `hour`, `day`, `day-hours`, `month` or `year`. Defaults to `day`.
+            timezone (str): IANA Time Zone (e.g. America/Phoenix).
+                            Defaults to the requester's timezone.
+                            When the requester's timezone isn't present, then `filters.from` is parsed to get the timezone.
+            filters (dict): If none provided, your report will span the last seven days.
+            payload (dict): Custom payload to be used as request's data.
+                            It overrides all other parameters provided for the method.
+            headers (dict): Custom headers to be used with session headers.
+                            They will be merged with session-level values that are set,
+                            however, these method-level parameters will not be persisted across requests.
+
+        Returns:
+            httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/chats/queued_visitors_left',
+                                 json=payload,
+                                 headers=headers)
+
 # Agents
 
     def availability(self,
@@ -347,7 +440,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -377,7 +470,7 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
@@ -385,7 +478,6 @@ class ReportsApiV36(HttpClient):
                                  json=payload,
                                  headers=headers)
 
-
 # Tags
 
     def chat_usage(self,
@@ -408,10 +500,43 @@ class ReportsApiV36(HttpClient):
 
         Returns:
             httpx.Response: The Response object from `httpx` library,
-                                which contains a server’s response to an HTTP request.
+                                which contains a server's response to an HTTP request.
         '''
         if payload is None:
             payload = prepare_payload(locals())
         return self.session.post(f'{self.api_url}/tags/chat_usage',
                                  json=payload,
                                  headers=headers)
+
+
+# Customers
+
+    def unique_visitors(self,
+                        distribution: str = None,
+                        timezone: str = None,
+                        filters: dict = None,
+                        payload: dict = None,
+                        headers: dict = None) -> httpx.Response:
+        ''' Shows the total number of page views and unique visitors for the specified period.
+
+        Args:
+            distribution (str): Allowed values: `hour`, `day`, `day-hours`, `month` or `year`. Defaults to `day`.
+            timezone (str): IANA Time Zone (e.g. America/Phoenix).
+                            Defaults to the requester's timezone.
+                            When the requester's timezone isn't present, then `filters.from` is parsed to get the timezone.
+            filters (dict): If none provided, your report will span the last seven days.
+            payload (dict): Custom payload to be used as request's data.
+                            It overrides all other parameters provided for the method.
+            headers (dict): Custom headers to be used with session headers.
+                            They will be merged with session-level values that are set,
+                            however, these method-level parameters will not be persisted across requests.
+
+        Returns:
+            httpx.Response: The Response object from `httpx` library,
+                                which contains a server's response to an HTTP request.
+        '''
+        if payload is None:
+            payload = prepare_payload(locals())
+        return self.session.post(f'{self.api_url}/customers/unique_visitors',
+                                 json=payload,
+                                 headers=headers)
